# -*- mode: ruby; coding: utf-8 -*-
# Copyright (c) 2019
# Author: Tyler Cunnion
# Created: 2019-May-08 17:14 (EDT)
# Function: Deduce Ingest API

module Rack
  module Deduce
    class Ingest::Railtie < Rails::Railtie
      config.deduce_ingest = ActiveSupport::OrderedOptions.new

      initializer "rack.deduce.ingest.initializer" do |app|
        site_id     = app.config.deduce_ingest[:site_id]
        apikey      = app.config.deduce_ingest[:apikey]
        ssl         = app.config.deduce_ingest[:ssl]

        raise "A unique site identifier is required to use the deduce ingest API.\nContact Deduce (http://www.deduce.com) if you do not have one." unless site_id && apikey

        options = {}
        options[:ssl]         = ssl
        options[:testmode]    = app.config.deduce_ingest[:testmode]

        Rack::Deduce::Ingest.new app, site_id, apikey, options
      end

      initializer "rack.deduce.ingest.helpers" do
        ActionView::Base.send :include, Rack::Deduce::Ingest::Helpers
        ActionController::Base.send :include, Rack::Deduce::Ingest::Helpers
      end

    end
  end
end
